document.addEventListener('DOMContentLoaded', () => {
  // Mobile menu toggle
  const menuToggle = document.querySelector('.menu-toggle');
  const navLinks = document.querySelector('.nav-links');

  menuToggle.addEventListener('click', () => {
    navLinks.classList.toggle('active');
    menuToggle.classList.toggle('active');
  });

  // Smooth scroll for navigation links
  document.querySelectorAll('a[href^="#"]').forEach(anchor => {
    anchor.addEventListener('click', function (e) {
      e.preventDefault();
      const target = document.querySelector(this.getAttribute('href'));
      if (target) {
        target.scrollIntoView({
          behavior: 'smooth'
        });
        navLinks.classList.remove('active');
      }
    });
  });

  // ASN Lookup functionality
  const searchBtn = document.getElementById('search-btn');
  const asnInput = document.getElementById('asn-input');
  const resultDiv = document.getElementById('result');

  searchBtn.addEventListener('click', () => {
    const asn = asnInput.value.trim();
    if (!asn) {
      resultDiv.innerHTML = '<p class="error">Please enter an ASN</p>';
      return;
    }

    // Simulate API call with loading state
    resultDiv.innerHTML = '<p class="loading">Searching...</p>';
    
    // This is a mock response - in a real implementation, you would call an actual API
    setTimeout(() => {
      const mockData = {
        asn: asn,
        name: "Example Network",
        country: "United States",
        prefix_count: 1234,
        description: "Example ASN for demonstration purposes"
      };

      resultDiv.innerHTML = `
        <div class="result-card">
          <h3>ASN Information</h3>
          <p><strong>ASN:</strong> ${mockData.asn}</p>
          <p><strong>Name:</strong> ${mockData.name}</p>
          <p><strong>Country:</strong> ${mockData.country}</p>
          <p><strong>Prefix Count:</strong> ${mockData.prefix_count}</p>
          <p><strong>Description:</strong> ${mockData.description}</p>
        </div>
      `;
    }, 1000);
  });

  // Handle Enter key in input
  asnInput.addEventListener('keypress', (e) => {
    if (e.key === 'Enter') {
      searchBtn.click();
    }
  });
});
